@@ -1,11 +1,11 @@
 from io import BytesIO
 from typing import List, Union
 
-from .static_meme import static_memes
-from .gif_meme import gif_memes
+from .normal_meme import normal_memes
+from .gif_subtitle_meme import gif_subtitle_memes
 
 
-memes = {**static_memes, **gif_memes}
+memes = {**normal_memes, **gif_subtitle_memes}
 
 
 async def make_meme(type: str, texts: List[str]) -> Union[str, BytesIO]:
